import { request, getRequestParams } from '@/utils/request';
import { getUserInfo } from '@/utils/auth';

/**
 * 得到语言列表
 */
export function GetLanguageList() {
  let params = getRequestParams('language_manager-GetLanguageList');

  return request({
    method: 'post',
    url: process.env.VUE_APP_FileServer,
    params,
    data: {}
  });
}

/**
 * 获取词汇包
 * @param { Object } language_type 语言类型 word_key_list 词汇键值列表
 */
export function GetWordPack(data) {
  return request({
    method: 'post',
    url: process.env.VUE_APP_FileServer + '?MethodName=language_manager-GetWordPack',
    data
  });
}

/**
 * 上传文件
 * @param {String} SecurityLevel 保密级别
 */
export function fileUpload(SecurityLevel, file) {
  const { session_id, user_code, user_type } = getUserInfo();
  let params = {
    UserCode: user_code,
    UserType: user_type,
    SessionID: session_id,
    SecurityLevel
  };
  const formData = new FormData();
  formData.append(file.filename, file.file, file.file.name);

  return request({
    method: 'post',
    url: '/GCLSFileServer/WebFileUpload',
    timeout: 0,
    params,
    headers: {
      'Content-Type': 'multipart/form-data'
    },
    data: formData
  });
}

/**
 * 得到文件存储信息
 * @param {Object} data { file_id 文件ID }
 */
export function GetFileStoreInfo(data) {
  let params = getRequestParams('file_store_manager-GetFileStoreInfo');

  return request({
    method: 'post',
    url: process.env.VUE_APP_FileServer,
    params,
    data
  });
}
